@@ -7,9 +7,9 @@
 """
     @package
     Output: CSV (comma-separated)
-    Grouped By: Value
+    Grouped By: Value, Symbol Name, Footprint, DNP
     Sorted By: Ref
-    Fields: Item, Qty, Reference(s), Value, LibPart, Footprint, Datasheet, all additional symbol fields
+    Fields: Item, Qty, Reference(s), Value, LibPart, Footprint, Datasheet, DNP, all additional symbol fields
 
     Outputs ungrouped components first, then outputs grouped components.
 
@@ -45,6 +45,8 @@ def myEqu(self, other):
         result = False
     elif self.getFootprint() != other.getFootprint():
         result = False
+    elif self.getDNP() != other.getDNP():
+        result = False
 
     return result
 
@@ -64,16 +66,18 @@ net = kicad_netlist_reader.netlist(sys.argv[1])
 
 # Open a file to write to, if the file cannot be opened output to stdout
 # instead
+canOpenFile = True
 try:
     f = kicad_utils.open_file_writeUTF8(sys.argv[2], 'w')
 except IOError:
     e = "Can't open output file for writing: " + sys.argv[2]
     print( __file__, ":", e, sys.stderr )
     f = sys.stdout
+    canOpenFile = False
 
 # subset the components to those wanted in the BOM, controlled
 # by <configure> block in kicad_netlist_reader.py
-components = net.getInterestingComponents()
+components = net.getInterestingComponents( excludeBOM=True )
 
 compfields = net.gatherComponentFieldUnion(components)
 partfields = net.gatherLibPartFieldUnion()
@@ -84,7 +88,8 @@ partfields -= set( ['Reference', 'Value', 'Datasheet', 'Footprint'] )
 columnset = compfields | partfields     # union
 
 # prepend an initial 'hard coded' list and put the enchillada into list 'columns'
-columns = ['Item', 'Qty', 'Reference(s)', 'Value', 'LibPart', 'Footprint', 'Datasheet'] + sorted(list(columnset))
+hardcoded_columns = ['Item', 'Qty', 'Reference(s)', 'Value', 'LibPart', 'Footprint', 'Datasheet', 'DNP']
+columns = hardcoded_columns + sorted(list(columnset))
 
 # Create a new csv writer object to use as the output formatter
 out = csv.writer( f, lineterminator='\n', delimiter=',', quotechar='\"', quoting=csv.QUOTE_ALL )
@@ -103,39 +108,12 @@ writerow( out, ['Tool:', net.getTool()] )
 writerow( out, ['Generator:', sys.argv[0]] )
 writerow( out, ['Component Count:', len(components)] )
 writerow( out, [] )
-writerow( out, ['Individual Components:'] )
-writerow( out, [] )                        # blank line
-writerow( out, columns )
-
-# Output all the interesting components individually first:
-row = []
-for c in components:
-    del row[:]
-    row.append('')                                      # item is blank in individual table
-    row.append('')                                      # Qty is always 1, why print it
-    row.append( c.getRef() )                            # Reference
-    row.append( c.getValue() )                          # Value
-    row.append( c.getLibName() + ":" + c.getPartName() ) # LibPart
-    #row.append( c.getDescription() )
-    row.append( c.getFootprint() )
-    row.append( c.getDatasheet() )
-
-    # from column 7 upwards, use the fieldnames to grab the data
-    for field in columns[7:]:
-        row.append( c.getField( field ) );
-
-    writerow( out, row )
-
-
-writerow( out, [] )                        # blank line
-writerow( out, [] )                        # blank line
-writerow( out, [] )                        # blank line
 
 writerow( out, ['Collated Components:'] )
 writerow( out, [] )                        # blank line
 writerow( out, columns )                   # reuse same columns
 
-
+row=[]
 
 # Get all of the components in groups of matching parts + values
 # (see kicad_netlist_reader.py)
@@ -147,17 +125,18 @@ item = 0
 for group in grouped:
     del row[:]
     refs = ""
+    refs_l = []
 
     # Add the reference of every component in the group and keep a reference
     # to the component so that the other data can be filled in once per group
     for component in group:
-        if len(refs) > 0:
-            refs += ", "
-        refs += component.getRef()
+        refs_l.append( component.getRef() )
         c = component
-
+    
+    refs = ", ".join(refs_l)
+    
     # Fill in the component groups common data
-    # columns = ['Item', 'Qty', 'Reference(s)', 'Value', 'LibPart', 'Footprint', 'Datasheet'] + sorted(list(columnset))
+    # columns = ['Item', 'Qty', 'Reference(s)', 'Value', 'LibPart', 'Footprint', 'Datasheet', 'DNP'] + sorted(list(columnset))
     item += 1
     row.append( item )
     row.append( len(group) )
@@ -166,11 +145,15 @@ for group in grouped:
     row.append( c.getLibName() + ":" + c.getPartName() )
     row.append( net.getGroupFootprint(group) )
     row.append( net.getGroupDatasheet(group) )
+    row.append( c.getDNPString() )
 
-    # from column 7 upwards, use the fieldnames to grab the data
-    for field in columns[7:]:
+    # add user fields by name
+    for field in columns[len(hardcoded_columns):]:
         row.append( net.getGroupField(group, field) );
 
     writerow( out, row  )
 
 f.close()
+
+if not canOpenFile:
+    sys.exit(1)
