@@ -9,7 +9,7 @@
     Output: CSV (comma-separated)
     Grouped By: ungrouped, one component per line
     Sorted By: Ref
-    Fields: Ref, Value, Part, Footprint, Datasheet, Manufacturer, Vendor
+    Fields: Ref, Value, Part, Footprint, Datasheet, Manufacturer, Vendor, DNP
 
     Command line:
     python "pathToFile/bom_csv_sorted_by_ref.py" "%I" "%O.csv"
@@ -34,12 +34,14 @@ net = kicad_netlist_reader.netlist(sys.argv[1])
 
 # Open a file to write to, if the file cannot be opened output to stdout
 # instead
+canOpenFile = True
 try:
     f = kicad_utils.open_file_writeUTF8(sys.argv[2], 'w')
 except IOError:
     e = "Can't open output file for writing: " + sys.argv[2]
     print( __file__, ":", e, sys.stderr )
     f = sys.stdout
+    canOpenFile = False
 
 # Create a new csv writer object to use as the output formatter
 out = csv.writer(f, lineterminator='\n', delimiter=',', quotechar="\"", quoting=csv.QUOTE_ALL)
@@ -51,17 +53,20 @@ def writerow( acsvwriter, columns ):
         utf8row.append( fromNetlistText( str(col) ) )
     acsvwriter.writerow( utf8row )
 
-components = net.getInterestingComponents()
+components = net.getInterestingComponents( excludeBOM=True )
 
 # Output a field delimited header line
 writerow( out, ['Source:', net.getSource()] )
 writerow( out, ['Date:', net.getDate()] )
 writerow( out, ['Tool:', net.getTool()] )
 writerow( out, ['Component Count:', len(components)] )
-writerow( out, ['Ref', 'Value', 'Footprint', 'Datasheet', 'Manufacturer', 'Vendor'] )
+writerow( out, ['Ref', 'Value', 'Footprint', 'Datasheet', 'Manufacturer', 'Vendor', 'DNP'] )
 
 # Output all of the component information (One component per row)
 for c in components:
     writerow( out, [c.getRef(), c.getValue(), c.getFootprint(), c.getDatasheet(),
-        c.getField("Manufacturer"), c.getField("Vendor")])
+        c.getField("Manufacturer"), c.getField("Vendor"), c.getDNPString()])
 
+
+if not canOpenFile:
+    sys.exit(1)
\ No newline at end of file
